'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var ReactDOM = require('react-dom');
var PropTypes = _interopDefault(require('prop-types'));
var reactTransitionGroup = require('react-transition-group');
var classnames = _interopDefault(require('classnames'));

var canUseDOM = !!(typeof window !== 'undefined' && window.document && window.document.createElement);

var Portal = function Portal(_ref) {
  var node = _ref.node,
      children = _ref.children;
  // 使用ref记录内部创建的节点 初始值为null
  var defaultNodeRef = React.useRef(null); // 组件卸载时 移除该节点

  React.useEffect(function () {
    return function () {
      if (defaultNodeRef.current) {
        document.body.removeChild(defaultNodeRef.current);
      }
    };
  }, []); // 如果非浏览器环境 直接返回 null 服务端渲染需要

  if (!canUseDOM) return null; // 若用户未传入节点，Portal也未创建节点，则创建节点并添加至body

  if (!node && !defaultNodeRef.current) {
    var defaultNode = document.createElement('div');
    defaultNode.className = 'react-easy-popup__portal';
    defaultNodeRef.current = defaultNode;
    document.body.appendChild(defaultNode);
  }

  return ReactDOM.createPortal(children, node || defaultNodeRef.current);
};

Portal.propTypes = {
  node: canUseDOM ? /*#__PURE__*/PropTypes.instanceOf(HTMLElement) : PropTypes.any,
  children: PropTypes.node
};

// Popup默认属性
var defaultProps = {
  visible: false,
  position: 'center',
  mask: true,
  maskClosable: false,
  onClose: function onClose() {},
  destroyOnClose: false,
  wrapClassName: ''
};

var prefixCls = 'react-easy-popup'; // 动画时长

var duration = 300; // 位置与动画的映射

var animations = {
  bottom: prefixCls + "-slide-up",
  right: prefixCls + "-slide-left",
  left: prefixCls + "-slide-right",
  top: prefixCls + "-slide-down",
  center: prefixCls + "-fade"
};

var Popup = function Popup(props) {
  var _classnames;

  var firstRenderRef = React.useRef(false);
  var visible = props.visible;
  if (!firstRenderRef.current && !visible) return null;

  if (!firstRenderRef.current) {
    firstRenderRef.current = true;
  }

  var node = props.node,
      mask = props.mask,
      maskClosable = props.maskClosable,
      onClose = props.onClose,
      wrapClassName = props.wrapClassName,
      position = props.position,
      destroyOnClose = props.destroyOnClose,
      children = props.children; // 蒙层点击事件

  var onMaskClick = function onMaskClick() {
    if (maskClosable) {
      onClose();
    }
  }; // 拼接容器节点类名


  var rootCls = classnames(prefixCls, wrapClassName, prefixCls + "__" + position); // 拼接蒙层节点类名

  var maskCls = classnames(prefixCls + "-mask", (_classnames = {}, _classnames[prefixCls + "-mask__visible"] = mask, _classnames)); // 拼接内容节点类名

  var contentCls = classnames(prefixCls + "-content", prefixCls + "-content__" + position); // 内容过渡动画

  var contentAnimation = animations[position];
  return React.createElement(Portal, {
    node: node
  }, React.createElement("div", {
    className: rootCls
  }, React.createElement(reactTransitionGroup.CSSTransition, {
    in: visible,
    timeout: duration,
    classNames: prefixCls + "-fade",
    appear: true
  }, React.createElement("div", {
    className: maskCls,
    onClick: onMaskClick
  })), React.createElement(reactTransitionGroup.CSSTransition, {
    in: visible,
    timeout: duration,
    classNames: contentAnimation,
    unmountOnExit: destroyOnClose,
    appear: true
  }, React.createElement("div", {
    className: contentCls
  }, children))));
};

Popup.propTypes = {
  visible: PropTypes.bool,
  position: /*#__PURE__*/PropTypes.oneOf(['top', 'right', 'bottom', 'left', 'center']),
  mask: PropTypes.bool,
  maskClosable: PropTypes.bool,
  onClose: PropTypes.func,
  stopScrollUnderMask: PropTypes.bool,
  destroyOnClose: PropTypes.bool,
  wrapClassName: PropTypes.string
};
Popup.defaultProps = defaultProps;

exports.Popup = Popup;
exports.Portal = Portal;
//# sourceMappingURL=react-easy-popup.cjs.development.js.map
